@@ -6,6 +6,7 @@
 #' @param df The data source
 #' @param variable the variable, it should be numeric
 #' @param weight The weighting variable
+#' @param na.rm Remove NA values or not, defaults to TRUE
 #'
 #' @return a numeric value
 #' @export
@@ -18,9 +19,9 @@
 #'
 #' library(dplyr)
 #' illinois %>% wtd_mean(age, weight)
-wtd_mean <- function(df, variable, weight){
+wtd_mean <- function(df, variable, weight, na.rm = TRUE){
   df %>%
-    summarise(mean = weighted.mean(x = {{variable}}, w = {{weight}})) %>%
+    summarise(mean = weighted.mean(x = {{variable}}, w = {{weight}}, na.rm = na.rm)) %>%
     pull()
 }
 
